import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ScheduleConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule#description Schedule#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule#name Schedule#name}.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule#overflow Schedule#overflow}.
     *
     * @stability stable
     */
    readonly overflow?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule#teams Schedule#teams}.
     *
     * @stability stable
     */
    readonly teams?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule#time_zone Schedule#time_zone}.
     *
     * @stability stable
     */
    readonly timeZone: string;
    /**
     * layer block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule#layer Schedule#layer}
     *
     * @stability stable
     */
    readonly layer: ScheduleLayer[] | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface ScheduleLayerRestriction {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule#duration_seconds Schedule#duration_seconds}.
     *
     * @stability stable
     */
    readonly durationSeconds: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule#start_day_of_week Schedule#start_day_of_week}.
     *
     * @stability stable
     */
    readonly startDayOfWeek?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule#start_time_of_day Schedule#start_time_of_day}.
     *
     * @stability stable
     */
    readonly startTimeOfDay: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule#type Schedule#type}.
     *
     * @stability stable
     */
    readonly type: string;
}
export declare function scheduleLayerRestrictionToTerraform(struct?: ScheduleLayerRestriction | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface ScheduleLayer {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule#end Schedule#end}.
     *
     * @stability stable
     */
    readonly end?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule#name Schedule#name}.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule#rotation_turn_length_seconds Schedule#rotation_turn_length_seconds}.
     *
     * @stability stable
     */
    readonly rotationTurnLengthSeconds: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule#rotation_virtual_start Schedule#rotation_virtual_start}.
     *
     * @stability stable
     */
    readonly rotationVirtualStart: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule#start Schedule#start}.
     *
     * @stability stable
     */
    readonly start: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule#users Schedule#users}.
     *
     * @stability stable
     */
    readonly users: string[];
    /**
     * restriction block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule#restriction Schedule#restriction}
     *
     * @stability stable
     */
    readonly restriction?: ScheduleLayerRestriction[] | cdktf.IResolvable;
}
export declare function scheduleLayerToTerraform(struct?: ScheduleLayer | cdktf.IResolvable): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule pagerduty_schedule}.
 *
 * @stability stable
 */
export declare class Schedule extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule pagerduty_schedule} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ScheduleConfig);
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _overflow?;
    /**
     * @stability stable
     */
    get overflow(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set overflow(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOverflow(): void;
    /**
     * @stability stable
     */
    get overflowInput(): boolean | cdktf.IResolvable | undefined;
    private _teams?;
    /**
     * @stability stable
     */
    get teams(): string[];
    /**
     * @stability stable
     */
    set teams(value: string[]);
    /**
     * @stability stable
     */
    resetTeams(): void;
    /**
     * @stability stable
     */
    get teamsInput(): string[] | undefined;
    private _timeZone?;
    /**
     * @stability stable
     */
    get timeZone(): string;
    /**
     * @stability stable
     */
    set timeZone(value: string);
    /**
     * @stability stable
     */
    get timeZoneInput(): string | undefined;
    private _layer?;
    /**
     * @stability stable
     */
    get layer(): ScheduleLayer[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set layer(value: ScheduleLayer[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get layerInput(): cdktf.IResolvable | ScheduleLayer[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
